@@ -10,7 +10,10 @@ def alternate_strategy(inputs, strategy):
     return result
 
 
-def deviation(inputs, outputs, strategy):
+def pct_deviation(outputs, inputs, strategy):
+    return round(100 * deviation(outputs, inputs, strategy))
+
+def deviation(outputs, inputs, strategy):
     result = 0
     for n in range(len(inputs)):
         subset = inputs[:n]
@@ -72,7 +75,7 @@ class Strategy(models.TextChoices):
 # sub-second, or have a better strategy
 
 
-class Interaction(models.Model):
+class Dialog(models.Model):
     start_time = models.DateTimeField(auto_now_add=True)
     foil_strategy = models.CharField(choices=Strategy.choices, max_length=1)
     user_miscommunication  = models.FloatField()
@@ -98,11 +101,11 @@ class Interaction(models.Model):
         return user_result, foil_result
 
     def get_absolute_url(self):
-        return reverse('id_trust:interact', kwargs={'pk': self.pk})
+        return reverse('id_trust:blind_interact', kwargs={'pk': self.pk})
 
 
 class Exchange(models.Model):
-    interaction = models.ForeignKey(Interaction, on_delete=models.CASCADE)
+    interaction = models.ForeignKey(Dialog, on_delete=models.CASCADE)
     user_intent = models.BooleanField()
     user_effect = models.BooleanField()
     foil_intent = models.BooleanField()
