@@ -1,6 +1,6 @@
 from collections import OrderedDict
 from django.db.models import Max
-from django.shortcuts import render, redirect
+from django.shortcuts import render, redirect, get_object_or_404
 from django.urls import reverse
 from django.views.generic.base import TemplateView
 from django.views.generic.detail import DetailView
@@ -8,29 +8,31 @@ from django.views.generic.edit import CreateView, UpdateView
 import random
 
 from finitelycomputable.idtrust_django.models import (
-        Interaction, Exchange, Strategy, deviation,
+        Dialog, Exchange, Strategy, pct_deviation,
 )
 
 def trust_list_display(trust_list):
     return ", ".join(["Trust" if t else "Distrust" for t in trust_list])
 
-def home(request):
+
+def home(request, blind=True):
     if request.method != 'POST':
-        return render(request, 'id_trust/interaction_begin.html', {})
+        return render(request, 'id_trust/interaction_begin.html',
+                {'blind': blind})
     try:
         user_miscommunication = float(request.POST.get('user_miscommunication'))
     except (ValueError, TypeError):
-        user_miscommunication = 0.0
+        user_miscommunication = round(random.random() / 2, 2)
     try:
         foil_miscommunication = float(request.POST.get('foil_miscommunication'))
     except (ValueError, TypeError):
-        foil_miscommunication = 0.0
-    obj = Interaction.objects.create(
+        foil_miscommunication = round(random.random() / 2, 2)
+    obj = Dialog.objects.create(
         foil_strategy=random.choice(Strategy.choices)[0],
         user_miscommunication=user_miscommunication,
         foil_miscommunication=foil_miscommunication,
     )
-    interact_core(request, obj.pk)
+    interact_core(request, obj.pk, not blind)
     return redirect(obj)
 
 
@@ -38,9 +40,8 @@ def effect(intent, miscommunication):
     return intent ^ bool(miscommunication > random.random())
 
 
-def interact_core(request, pk):
-    from django.shortcuts import get_object_or_404
-    interaction = get_object_or_404(Interaction, pk=pk)
+def interact_core(request, pk, blind):
+    interaction = get_object_or_404(Dialog, pk=pk)
     foil_intent = Strategy.impl(interaction.foil_strategy)(
             [e.user_effect for e in interaction.exchange_set.all()])
     user_intent = request.POST.get('user_intent')
@@ -63,30 +64,32 @@ def interact_core(request, pk):
     user_effect = [j.user_effect for j in interaction.exchange_set.all()]
     foil_intent = [j.foil_intent for j in interaction.exchange_set.all()]
     foil_effect = [j.foil_effect for j in interaction.exchange_set.all()]
-    strategy_lists = OrderedDict()
+    strategy_list = []
     if len(user_intent):
         for (k, v) in Strategy.choices:
             st = Strategy.impl(k)
-            strategy_lists[v] = [deviation(user_intent, foil_intent, st)]
-            strategy_lists[v].append(deviation(foil_intent, user_intent, st))
-    s_results = [
-            "%s: (foil %.1f) (user %.1f)" %
-            (k, v[0], v[1]) for (k, v) in strategy_lists.items()]
-    score = interaction.score()
+            strategy_list.append({
+                'strategy': v,
+                'foil_intent': 100-pct_deviation(foil_intent, user_effect, st),
+                'foil_effect': 100-pct_deviation(foil_effect, user_effect, st),
+                'user_intent': 100-pct_deviation(user_intent, foil_effect, st),
+                'user_effect': 100-pct_deviation(user_effect, foil_effect, st),
+            })
+    strategy_list.sort(key=lambda t: t['foil_intent'], reverse=True)
     return {
         'interaction': interaction,
-        'score': score,
         'user_intent': trust_list_display(user_intent),
         'user_effect': trust_list_display(user_effect),
         'foil_effect': trust_list_display(foil_effect),
         'foil_intent': trust_list_display(foil_intent),
-        's_results': s_results,
+        'blind': blind,
+        'strategy_list': strategy_list,
         'strategies': Strategy,
     }
 
-def interact(request, pk):
+def interact(request, pk, blind):
     return render(request, 'id_trust/interaction.html',
-        interact_core(request, pk))
+        interact_core(request, pk, blind))
 
 
 class ExchangeCreate(CreateView):
@@ -118,7 +121,7 @@ class Home(CreateView):
     template_name = "id_trust/interaction_begin.html"
 
     def form_valid(self, form):
-        interaction = form.instance.interaction = Interaction.objects.create(
+        interaction = form.instance.interaction = Dialog.objects.create(
             foil_strategy = random.choice(Strategy.choices)[0]
         )
         form.instance.foil_trust = Strategy.impl(interaction.foil_strategy)(
@@ -134,7 +137,7 @@ class Home(CreateView):
 class Interact(DetailView):
     template_name = 'id_trust/interaction.html'
     fields = ['choice']
-    model = Interaction
+    model = Dialog
 
     def get_context_data(self, **kwargs):
         context = super(Interact, self).get_context_data(**kwargs)
